#!/usr/bin/env node

'use strict';

var path =  require('path');
var through = require('through');
var finished = require('tap-finished');
var growl = require('growl');

var tr = through();
process.stdin.pipe(tr).pipe(process.stdout);

function init() {
    tr.pipe(finished(function (results) {
        var failed = results.fail.length + results.errors.length;
        var total = results.plan.end;
        notify(failed, total);
        init(); // keep watching for next test run
    }));
}

init();

function image (name) {
  return path.join(__dirname, '../images/' , name + '.png');
}

function notify (failed, total) {
    var growlOptions = {
        name: 'tap',
        title: failed ? 'Failed' : 'Passed',
        image: image(failed ? 'error' : 'ok')
    };

    var message;
    if (failed) {
        message = failed + ' of ' + total + ' tests failed';
    } else {
        message = total + ' tests passed';
    }

    return growl(message, growlOptions);
}
